kafkaesquejars: Java Archive Wrapper Supporting the 'kafkaesque' Package

Description Author(s) Examples

Description

Kafka is a big data technology providing a scalable, persistent, distributed, high throughput event log to which clients can subscribe topics or publish messages.

Author(s)

Peter Meissner retep.meissner@gmail.com

Examples

1

petermeissner/kafkaesquejars documentation built on Dec. 31, 2020, 1:18 a.m.