Description Author(s) Examples
Kafka is a big data technology providing a scalable, persistent, distributed, high throughput event log to which clients can subscribe topics or publish messages.
Peter Meissner retep.meissner@gmail.com
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.